@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: Relay.pm 80 2007-08-24 17:02:58Z jeff $
+# $Id: Relay.pm 71 2007-08-14 00:33:05Z jeff $
 #
 # Authors:
 #      Jeff Buchbinder <jeff@freemedsoftware.org>
@@ -35,7 +35,7 @@ use HTTP::Cookies;
 
 use vars qw{ $VERSION };
 BEGIN {
-	$VERSION = '0.2.2';
+	$VERSION = '0.2';
 }
 
 sub new {
@@ -93,7 +93,7 @@ sub call {
 	foreach my $param (@params) {
 		print "param = '$param'\n";
 		if ( $param =~ /^HASH\(/ && $param->{'@var'} ) {
-			print "Found file upload var in $param->{'@var'}\n" if ($self->{'debug'});
+			print "Found file upload var in $param->{'@var'}\n" if (@self->{debug});
 			# Add file transfer under @var = var, @filename = filename
 			$p{$param->{'@var'}} = [ $param->{'@filename'} ];
 		} else {
@@ -125,7 +125,7 @@ __END__
 
 =pod
 
-=head1 NAME
+=head NAME
 
 FreeMED::Relay
 
@@ -135,10 +135,6 @@ Provide access to FreeMED 0.9.x+ data relay
 
 =head1 DESCRIPTION
 
-Backend access to the FreeMED Electronic Medical Record and Practice
-Management system ( http://freemedsoftware.org/ ) for versions begining
-with 0.9.0 using the JSON transport capabilities of its data relay.
-
 =head1 METHODS
 
 =over 4
